package org.greenstone.atea.morphia;

import dev.morphia.annotations.*;
import java.util.ArrayList;
import java.util.List;

/**
 * Morphia provides the Object Document Mapper for MongoDB
 * https://www.baeldung.com/mongodb-morphia 
 * 
 */
@Entity("Webpages")
public class WebpageInfo {

    /** db table ids */
    @Id
    public final long webpageID;
    // TODO: should this be a "Reference" to the WebsiteInfo object instead?
    // See section 5.2 of https://www.baeldung.com/mongodb-morphia
    public final String websiteID; //int websiteID;

    public final int totalSentences;
    
    public final String text;
    public final String URL;
    public final boolean isMRI;    
	
    public final String charEncoding;
    public final String modifiedTime;
    public final String fetchTime;

    @Embedded
    public final List<SentenceInfo> singleSentences;
    @Embedded
    public final List<SentenceInfo> overlappingSentences;

    private int mriSentenceCount;    
    private boolean containsMRI;
    
    public WebpageInfo (long webpageID, String siteID/*int websiteID,*/,
			String pageText, String pageURL, boolean isMRI, int totalSentences,
			String charEncoding, String modifiedTime, String fetchTime,
			List<SentenceInfo> singleSentences,
			List<SentenceInfo> overlappingSentences)
    {

	this.webpageID = webpageID;
	//this.websiteID = websiteID;
	this.websiteID = siteID;

	this.totalSentences = totalSentences;
	
	this.text = pageText;
	this.URL = pageURL;
	this.isMRI = isMRI;
	
	this.charEncoding = charEncoding;
	this.modifiedTime = modifiedTime;
	this.fetchTime = fetchTime;

	this.singleSentences = singleSentences;
	this.overlappingSentences = overlappingSentences;
	
    }

    public void setMRISentenceCount(int count) {
	this.mriSentenceCount = count;
    }
    public void setContainsMRI(boolean containsMRI) {
	this.containsMRI = containsMRI;
    }

    public int getMRISentenceCount() { return this.mriSentenceCount; }
}
